@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.9.4.2 1999/05/27 14:03:58 martin Exp $ */
+/* $Id: msg_limits.c,v 1.9.4.3 2000/02/13 15:47:58 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -76,7 +76,7 @@ static struct nlist nlst [] = {
 void
 glibtop_init_msg_limits_p (glibtop *server)
 {
-	if (kvm_nlist (server->machine.kd, nlst) != 0) {
+	if (kvm_nlist (server->machine.kd, nlst) < 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
 		return;
 	}
