@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.7.4.2 1999/05/27 14:03:59 martin Exp $ */
+/* $Id: netload.c,v 1.7.4.3 2000/02/13 15:47:58 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -67,7 +67,7 @@ glibtop_init_netload_p (glibtop *server)
 {
     server->sysdeps.netload = _glibtop_sysdeps_netload;
 
-    if (kvm_nlist (server->machine.kd, nlst) != 0)
+    if (kvm_nlist (server->machine.kd, nlst) < 0)
 	glibtop_error_io_r (server, "kvm_nlist");
 }
 
